@@ -389,11 +389,8 @@ class NamedMatrix(object):
         
         mat.rownames = rownames
         
-        if not sorted(rownames) == rownames:
-            mat = mat.filter(rows=sorted(rownames))
-        
-        if not sorted(colnames) == colnames:
-            mat = mat.filter(columns=sorted(colnames))
+        if not sorted(rownames) == rownames or not sorted(colnames) == colnames:
+            mat = mat[sorted(rownames),sorted(colnames)]
         
         return mat
     
